@@ -84,7 +84,7 @@ void RadialMap::Widget::paintExplodedLabels(QPainter &paint) const
 
         //**** Levels should be on a scale starting with 0
         //**** range is a useless parameter
-        //**** keep a topblock var which is the lowestLevel OR startLevel for identation purposes
+        //**** keep a topblock var which is the lowestLevel OR startLevel for indentation purposes
         for (unsigned int i = startLevel; i <= m_map.m_visibleDepth; ++i) {
             for (const Segment *segment : m_map.m_signature[i]) {
                 if (segment->start() >= start && segment->end() <= end) {
@@ -202,7 +202,7 @@ void RadialMap::Widget::paintExplodedLabels(QPainter &paint) const
                 font.setPointSize(sizes[label->level]);
             }
             QFontMetrics fontMetrics(font);
-            const int minTextWidth = fontMetrics.width(QString::fromLatin1("M...")) + LABEL_TEXT_HMARGIN; // Fully elided string
+            const int minTextWidth = fontMetrics.width(QStringLiteral("M...")) + LABEL_TEXT_HMARGIN; // Fully elided string
 
             const int fontHeight  = fontMetrics.height() + LABEL_TEXT_VMARGIN; //used to ensure label texts don't overlap
             const int lineSpacing = fontHeight / 4;
